@@ -23,16 +23,20 @@ DGUI_USE_NAMESPACE
 DataModel::DataModel(QObject *parent)
     : QAbstractTableModel(parent)
 {
+    qDebug() << "DataModel constructor called";
     m_pMimetype = new MimeTypeDisplayManager(this);
+    qDebug() << "DataModel initialized with MimeTypeDisplayManager";
 }
 
 DataModel::~DataModel()
 {
+    qDebug() << "DataModel destructor called";
 
 }
 
 QVariant DataModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
+    qDebug() << "Getting header data for section:" << section << "role:" << role;
     Q_UNUSED(orientation)
 
     if (Qt::DisplayRole == role) {
@@ -46,6 +50,7 @@ QVariant DataModel::headerData(int section, Qt::Orientation orientation, int rol
 
 QVariant DataModel::data(const QModelIndex &index, int role) const
 {
+    qDebug() << "Getting data for index:" << index << "role:" << role;
     int iRow = index.row();
     int iColumn = index.column();
 
@@ -138,13 +143,16 @@ int DataModel::columnCount(const QModelIndex &parent) const
 
 void DataModel::refreshFileEntry(const QList<FileEntry> &listEntry)
 {
-    beginResetModel();//在开始添加此函数
+    qDebug() << "Refreshing file entries, count:" << listEntry.size();
+    beginResetModel();
     m_listEntry = listEntry;
-    endResetModel();  //在结束前添加此函数
+    endResetModel();
+    qDebug() << "File entries refreshed successfully";
 }
 
 QItemSelection DataModel::getSelectItem(const QStringList &listName)
 {
+    qDebug() << "Getting selection for items:" << listName;
     QItemSelection selection;
 
     for (int i = 0; i < m_listEntry.size(); ++i) {
@@ -163,6 +171,7 @@ QItemSelection DataModel::getSelectItem(const QStringList &listName)
 
 QModelIndex DataModel::getListEntryIndex(const QString &listName)
 {
+    qDebug() << "Getting index for entry:" << listName;
     for (int i = 0; i < m_listEntry.size(); ++i) {
         QModelIndex index = this->index(i, DC_Name);
         // 处理是否需要选中的文件
@@ -176,6 +185,7 @@ QModelIndex DataModel::getListEntryIndex(const QString &listName)
 
 void DataModel::sort(int column, Qt::SortOrder order)
 {
+    qDebug() << "Sorting by column:" << column << "order:" << order;
     if (0 > column || 3 < column) {
         return;
     }
